@@ -54,7 +54,7 @@ class TestEvent(object):
 
     @property
     def EventDurationSeconds(self) -> float:
-        if not self._start or self._end:
+        if not self.__start or self.__end:
             return 0.0
         else:
             if not self.__duration:
